
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef mocap_TCLSERV_CLIENT_ERROR_H
#define mocap_TCLSERV_CLIENT_ERROR_H

#include <server/mocapError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum mocap_error {
	E_mocap_OK					  			= 0,

	/* module errors */
	E_mocap_WRONG_OBJECT_ID                = S_mocap_WRONG_OBJECT_ID,
	E_mocap_MOTION_SYSTEM_NOT_FOUND        = S_mocap_MOTION_SYSTEM_NOT_FOUND,
	E_mocap_MODULE_NOT_INITIALIZED         = S_mocap_MODULE_NOT_INITIALIZED,


	/* std errors */
	E_mocap_ACTIVITY_INTERRUPTED           = S_mocap_stdGenoM_ACTIVITY_INTERRUPTED,
	E_mocap_TOO_MANY_ACTIVITIES            = S_mocap_stdGenoM_TOO_MANY_ACTIVITIES,
	E_mocap_ACTIVITY_FAILED                = S_mocap_stdGenoM_ACTIVITY_FAILED,
	E_mocap_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_mocap_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_mocap_UNKNOWN_ACTIVITY               = S_mocap_stdGenoM_UNKNOWN_ACTIVITY,
	E_mocap_FORBIDDEN_ACTIVITY_TRANSITION  = S_mocap_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_mocap_SYSTEM_ERROR                   = S_mocap_stdGenoM_SYSTEM_ERROR,
	E_mocap_ACTIVITY_ALREADY_ENDED         = S_mocap_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_mocap_WAIT_INIT_RQST                 = S_mocap_stdGenoM_WAIT_INIT_RQST,
	E_mocap_CONTROL_CODEL_ERROR            = S_mocap_stdGenoM_CONTROL_CODEL_ERROR,
	E_mocap_EXEC_TASK_SUSPENDED            = S_mocap_stdGenoM_EXEC_TASK_SUSPENDED,
	E_mocap_BAD_BLOCK_TYPE                 = S_mocap_stdGenoM_BAD_BLOCK_TYPE,
	E_mocap_BAD_POSTER_TYPE                = S_mocap_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum mocap_error mocap_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int mocap_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the mocap context.
 *
 * Returns NULL in case of failure
 */
const char* mocap_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
